
#include "TArtAnaLoopNEBULA.hh"

#include <iostream>

#include "TArtAnaFile.hh"
#include "TArtAnaClock.hh"

#include "TArtCalibNEBULA.hh"
#include "TArtNEBULAPla.hh"
#include "TArtNEBULAPlaPara.hh"
#include "TArtNEBULAParameters.hh"

#include "EAnalyser.hh"
#include "EWNum.hh"

TArtAnaLoopNEBULA::TArtAnaLoopNEBULA()
  : TArtAnaLoop(), calibnebula(0), nebulaparameters(0)
{;}

TArtAnaLoopNEBULA::~TArtAnaLoopNEBULA()
{
  Destruct();
}

void TArtAnaLoopNEBULA::Construct()
{
  nebulaparameters = new TArtNEBULAParameters;
  nebulaparameters->LoadParameter("db/NEBULA.xml");
  calibnebula= new TArtCalibNEBULA;//must be called after parameter is constructed
}

void TArtAnaLoopNEBULA::Calculate()
{
  calibnebula->LoadRawData();
  calibnebula->ReconstructData();

  Int_t NumNEBULAPla = calibnebula->GetNumNEBULAPla();
  for(int i=0; i<NumNEBULAPla; ++i){
    TArtNEBULAPla* pla = calibnebula->GetNEBULAPla(i);
    if(pla->GetDataState() < 0) continue;
    if(pla->GetIHitMin() < 4) continue;

    int tu = pla->GetTURaw();
    int td = pla->GetTDRaw();
    int qu = pla->GetQURaw();
    int qd = pla->GetQDRaw();
    int id = pla->GetID();

    Add(Analyser::NEBULA, WNum::NEBULA::ID,    id, id);
    Add(Analyser::NEBULA, WNum::NEBULA::TURaw, id, tu);
    Add(Analyser::NEBULA, WNum::NEBULA::TDRaw, id, td);
    Add(Analyser::NEBULA, WNum::NEBULA::QURaw, id, qu);
    Add(Analyser::NEBULA, WNum::NEBULA::QDRaw, id, qd);
  }

  calibnebula->ClearData();
}

//    TArtNEBULAPlaPara* parau = calibnebula->FindNEBULAPlaPara(pla->GetID(), "U");
//    TArtNEBULAPlaPara* parad = calibnebula->FindNEBULAPlaPara(pla->GetID(), "D");
//    std::cout << *parau << std::endl;
//    std::cout << *parad << std::endl;

void TArtAnaLoopNEBULA::Destruct()
{
  delete calibnebula;
  calibnebula = 0;
  delete nebulaparameters;
  nebulaparameters = 0;
}

const char* TArtAnaLoopNEBULA::ClassName() const
{
  return "TArtAnaLoopNEBULA";
}
