/*
 *    TArtStoreManager.cc
 *
 *    by T. Isobe
 */

#include "TArtCore.h"
#include "TArtRawEventObject.h"
#include "TArtEventInfo.h"
#include "TArtStoreManager.h"

#include "TBranch.h"
#include "TObjArray.h"
#include "TClonesArray.h"

TArtStoreManager* TArtStoreManager::sStoreManager = 0;
//////////////////////////////////////////////////

TArtStoreManager::TArtStoreManager() 
{
   TArtCore::Info("TArtStoreManager","Constructor");
   listOfParameters = new TList();
   listOfDataContainers = new TList();
}

TArtStoreManager::~TArtStoreManager()
{
  sStoreManager = 0;
  delete listOfParameters;
  listOfParameters = 0;
  delete listOfDataContainers;
  listOfDataContainers = 0;
}

void TArtStoreManager::AddParameters(TNamed *obj) {
  TArtCore::Info(__FILE__,"regist parameter in store manager : %s", obj->GetName());
  listOfParameters->Add(obj);
}

void TArtStoreManager::AddDataContainer(TArtRawEventObject *obj) {
  TArtCore::Info(__FILE__,"regist raw data container in store manager : %s", obj->GetName());
  listOfDataContainers->Add(obj);
}

void TArtStoreManager::AddDataContainer(TClonesArray *obj) {
  TArtCore::Info(__FILE__,"Regist data container in store manager : %s", obj->GetName());
  listOfDataContainers->Add(obj);
}


TArtStoreManager* TArtStoreManager::Instance() {
  if (!sStoreManager) sStoreManager = new TArtStoreManager();
  return sStoreManager;   
}

void TArtStoreManager::LoadDataFromTree(TTree *tree)
{

  TBranch *branch;
  TObjArray *branchArray = tree->GetListOfBranches();
  for (Int_t i=0; i<(size_t)(branchArray->GetEntriesFast()); i++) {      
    branch = (TBranch *) ((*branchArray)[i]);
    if(strcmp(branch->GetClassName(),"TClonesArray") == 0){
      TClonesArray *ca = NULL;
      tree->SetBranchAddress(branch->GetName(), &ca);
      ca->SetName(branch->GetName());
      AddDataContainer(ca);
    }
    else{
      continue;
    }
    TArtCore::Info(__FILE__,"Loading data container: %s, class: %s",branch->GetName(), branch->GetClassName());
  }

  return;
}
