#ifndef _TARTNEBULAPLAPARA_H_
#define _TARTNEBULAPLAPARA_H_

#include "TArtMap.h"
#include "segidlist.h"

class TArtNEBULAParameters;

class TArtNEBULAPlaPara : public TObject
{
  friend class TArtNEBULAParameters;

public:
  TArtNEBULAPlaPara(Int_t id = -1, const TString& udlr = "", const TString& detname = "",
		    Int_t fpl = -1, Int_t layer = -1, Int_t sublayer = -1, const Double_t* pos = 0, 
		    Double_t tcal = 1, Double_t toff = 0, Double_t tslw = 0,
		    Double_t qcal = 1, Double_t qped = 0,
		    Double_t dtcal = 1, Double_t dtoff = 0,
		    Int_t ignore = 0)
    : TObject(),
      fID(id), fUDLR(udlr), fDetName(detname),
      fFPl(fpl), fLayer(layer), fSubLayer(sublayer),
      fTCal(tcal), fTOff(toff), fTSlw(tslw),
      fQCal(qcal), fQPed(qped),
      fDTCal(dtcal), fDTOff(dtoff),
      fIgnore(ignore)
  {
    if(pos) for(int i=0; i<3; ++i) fPos[i] = pos[i];
    else for(int i=0; i<3; ++i) fPos[i] = 0;
  }
  ~TArtNEBULAPlaPara(){;}

  void SetID(Int_t val){fID = val;}
  void SetUDLR(const TString& val){fUDLR = val;}
  void SetDetectorName(const TString& val){fDetName = val;}
  void SetFPl(Int_t val){fFPl = val;}
  void SetLayer(Int_t val){fLayer = val;}
  void SetSubLayer(Int_t val){fSubLayer = val;}
  void SetPos(const Double_t* val){for(int i=0; i<3; ++i) fPos[i] = val[i];}
  void SetPos(Double_t val, Int_t i){fPos[i] = val;} 
  void SetTCal(Double_t val){fTCal = val;} 
  void SetTOff(Double_t val){fTOff = val;} 
  void SetTSlw(Double_t val){fTSlw = val;} 
  void SetQCal(Double_t val){fQCal = val;} 
  void SetQPed(Double_t val){fQPed = val;} 
  void SetDTCal(Double_t val){fDTCal = val;} 
  void SetDTOff(Double_t val){fDTOff = val;} 
  void SetIgnore(Int_t val){fIgnore = val;}

  Int_t GetID() const {return fID;}
  const TString& GetUDLR() const {return fUDLR;}
  const TString& GetDetectorName() const {return fDetName;}
  Int_t GetFPl() const {return fFPl;}
  Int_t GetLayer() const {return fLayer;}
  Int_t GetSubLayer() const {return fSubLayer;}
  const Double_t* GetPos() const {return fPos;} 
  Double_t GetPos(int i) const {return fPos[i];} 
  Double_t GetTCal() const {return fTCal;} 
  Double_t GetTOff() const {return fTOff;} 
  Double_t GetTSlw() const {return fTSlw;} 
  Double_t GetQCal() const {return fQCal;} 
  Double_t GetQPed() const {return fQPed;} 
  Double_t GetDTCal() const {return fDTCal;} 
  Double_t GetDTOff() const {return fDTOff;} 
  Int_t GetIgnore() const {return fIgnore;}

  friend ostream& operator<<(ostream& out, const TArtNEBULAPlaPara& p){
    out << "ID: " << p.fID << endl;
    out << "UDLR: " << p.fUDLR << endl;
    out << "DetectorName: " << p.fDetName << endl;
    out << "Focal Plane: " << p.fFPl << endl;
    out << "Layer: " << p.fLayer << endl;
    out << "SubLayer: " << p.fSubLayer << endl;
    out << "Position: " << p.fPos[0]<< " " << p.fPos[1]<< " " << p.fPos[2]<< endl;
    out << "T Calib: " << p.fTCal << endl;
    out << "T Offset: " << p.fTOff << endl;
    out << "T Slew: " << p.fTSlw << endl;
    out << "Q Calib: " << p.fQCal << endl;
    out << "Q Pedestal: " << p.fQPed << endl;
    out << "dT Calib: " << p.fDTCal << endl;
    out << "dT Offset: " << p.fDTOff << endl;
    out << "Ignore: " << p.fIgnore << endl;
    out << "Map of QDC: "  << p.fMapQDC << endl;
    out << "Map of TDC: "  << p.fMapTDC << endl;
    out << endl;
    return out;
  }

  const TArtRIDFMap& GetTDCMap() const {return fMapTDC;}
  const TArtRIDFMap& GetQDCMap() const {return fMapQDC;}

private:
  Int_t     fID;
  TString   fUDLR;
  TString   fDetName;
  Int_t     fFPl;
  Int_t     fLayer;
  Int_t     fSubLayer;
  Double_t  fPos[3];
  Double_t  fTCal;
  Double_t  fTOff;
  Double_t  fTSlw;
  Double_t  fQCal;
  Double_t  fQPed;
  Double_t  fDTCal;
  Double_t  fDTOff;
  Int_t     fIgnore;

  void SetMapTDC(Int_t tgeo, Int_t tch)
  {
    fMapTDC.SetMap(fFPl,41,tgeo,tch); 
    //    fMapTDC.SetMap(fpl,NEBULAT,tgeo,tch); 
    //    cout << "TDC is mapped to " << fMapTDC.GetMapInfo() << " " << fMapTDC.GetName() << endl;
  }
  void SetMapQDC(Int_t qgeo, Int_t qch)
  {
    fMapQDC.SetMap(fFPl,42,qgeo,qch); 
    //    fMapQDC.SetMap(fpl,NEBULAQ,qgeo,qch); 
    //    cout << "QDC is mapped to " << fMapQDC.GetMapInfo() << " " << fMapQDC.GetName() << endl;
  }    

  TArtRIDFMap fMapTDC;
  TArtRIDFMap fMapQDC;

  ClassDef(TArtNEBULAPlaPara,1);
};

#endif
